function [playerAdvantage] = advInsurance(deck);
%
% Calculate the average gain by taking the insurance bet. 
%  Assume unit bet for insurance.
%
% This is averaged over all hands, i.e. it accounts for the probability
% of the dealer showing an ace.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Blackjack Markov Chain Toolbox, v1.0 (08 Jan 2009)
%%% 
%%% Companion to manuscript 
%%%    "A Markov Chain Analysis of Blackjack Strategy"
%%%    by Michael B. Wakin and Christopher J. Rozell, 2004.
%%%    available at: http://inside.mines.edu/~mwakin/papers/mcbj.pdf
%%%
%%% Software Copyright 2009 by 
%%%    Michael B. Wakin, Colorado School of Mines, mwakin@mines.edu
%%%    Christopher J. Rozell, Georgia Tech, crozell@gatech.edu 
%%%
%%% This software is released under a Creative Commons license
%%% (Attribution 3.0 Unported): 
%%%     http://creativecommons.org/licenses/by/3.0/
%%% You are free:
%%%    * to Share  to copy, distribute and transmit the work
%%%    * to Remix  to adapt the work
%%% Under the following conditions:
%%%   * You must attribute the work by retaining this header information
%%%     crediting the original authors and linking to the original
%%%     manuscript.
%%%   * For any reuse or distribution, you must make clear to others the 
%%%     license terms of this work.
%%%   * Any of the above conditions can be waived if you get permission 
%%%     from the copyright holder.
%%%   * Nothing in this license impairs or restricts the author's 
%%%     moral rights.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


deck = deck/sum(deck);

% Chance of insurance opportunity
pAce = deck(1);

% Chance of dealer blackjack, given an ace showing
pBJ = deck(10);

% Player advantage
playerAdvantage = pAce*(2*pBJ - (1-pBJ));
