function setupVariables;
% Sets some global variables (to save on frequent initializations)
% Includes setting the house rules

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Blackjack Markov Chain Toolbox, v1.0 (08 Jan 2009)
%%% 
%%% Companion to manuscript 
%%%    "A Markov Chain Analysis of Blackjack Strategy"
%%%    by Michael B. Wakin and Christopher J. Rozell, 2004.
%%%    available at: http://inside.mines.edu/~mwakin/papers/mcbj.pdf
%%%
%%% Software Copyright 2009 by 
%%%    Michael B. Wakin, Colorado School of Mines, mwakin@mines.edu
%%%    Christopher J. Rozell, Georgia Tech, crozell@gatech.edu 
%%%
%%% This software is released under a Creative Commons license
%%% (Attribution 3.0 Unported): 
%%%     http://creativecommons.org/licenses/by/3.0/
%%% You are free:
%%%    * to Share  to copy, distribute and transmit the work
%%%    * to Remix  to adapt the work
%%% Under the following conditions:
%%%   * You must attribute the work by retaining this header information
%%%     crediting the original authors and linking to the original
%%%     manuscript.
%%%   * For any reuse or distribution, you must make clear to others the 
%%%     license terms of this work.
%%%   * Any of the above conditions can be waived if you get permission 
%%%     from the copyright holder.
%%%   * Nothing in this license impairs or restricts the author's 
%%%     moral rights.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


global PLAYERfirst PLAYERstartHard PLAYERmidHard PLAYERstartSoft PLAYERmidSoft PLAYERstartPair PLAYERterm PLAYERdoubTerm PLAYERtermSplit PLAYERblackjack PLAYERsurrender PLAYERbust PLAYERdoubBust

global DEALERfirst DEALERhard DEALERsoft DEALERterm DEALERblackjack DEALERbust

global houseRules
global playerMoves
global P PD Pinf PSinf PDinf 
global thorp basic

%%% Define playing rules
houseRules.DSSS = 1;       % Dealer stands on soft 17
houseRules.DASA = 1;       % Double after split allowed
houseRules.MSA = 0;        % Multiple splits allowed (code not configured for yes)
houseRules.HASAA = 0;      % Hit after split aces allowed (resplitting also allowed)
houseRules.SRA = 0;        % Late surrender allowed (after dealer checks for bj)
                           %   ...and before player draws cards

% State names for player transitions -- for speed these are not in a struct
%  first: have only one card, automatically draw another
%  startHard: two cards, options Hit/Stand/Double/Surrender (if rules allow)
%  midHard: three or more cards, options Hit/Stand
%  startSoft: two cards, options Hit/Stand/Double/Surrender 
%         (if rules allow)
%         Use startSoft12 for pair of Aces that can't be split.
%  midSoft: three or more cards, options Hit/Stand
%  startPair: two cards, options Hit/Stand/Double/Surrender/Split
%         (if rules allow)
%  term: hand finished
%  doubTerm: hand finished (bet doubled)
PLAYERfirst =     [0 1:10];
PLAYERstartHard = [0 0 0 11:28];
PLAYERmidHard =   [0 0 0 0 29:45];
PLAYERstartSoft = [zeros(1,11) 46:55];
PLAYERmidSoft =   [zeros(1,12) 56:64];
PLAYERstartPair = [0 65:74];         
PLAYERterm =      [0 0 0 75:92];      
PLAYERdoubTerm =  [zeros(1,5) 93:108];
PLAYERtermSplit = [0 109:118];
PLAYERblackjack = 119;
PLAYERsurrender = 120;
PLAYERbust =      121;
PLAYERdoubBust =  122;      
numPlayerStates = PLAYERdoubBust;

% State names for dealer transitions
DEALERfirst =     [0 1:10];
DEALERhard =      [0 0 0 11:24];
DEALERsoft =      [zeros(1,11) 25:30];
DEALERterm =      [zeros(1,16) 31:35];      
DEALERblackjack = 36;
DEALERbust =      37;   
numDealerStates = DEALERbust;

% Possible moves for the player (elements of strategy table)
playerMoves.S = 0;   % Stand
playerMoves.DB = 1;  % Double (else Hit)
playerMoves.DS = 2;  % Double (else Stand)
playerMoves.H = 3;   % Hit
playerMoves.SP = 4;  % Split
playerMoves.SR = 5;  % Surrender (else Hit)

% Transition matrices (initialize now because they are large)
P = zeros(11,numPlayerStates,numPlayerStates);      % Player's hand
PD = zeros(numDealerStates);                        % Dealer's hand

% "Infinite matrices" -- all probability in absorbing states
Pinf = zeros(11,numPlayerStates,numPlayerStates);   % Player's hand
PSinf = zeros(11,numPlayerStates,numPlayerStates);  % Player's hand after splitting a pair
PDinf = zeros(numDealerStates);                     % Dealer's hand

%%% Basic Strategy Tables

S = 0;   % Stand
DB = 1;  % Double (else Hit)
DS = 2;  % Double (else Stand)
H = 3;   % Hit
SP = 4;  % Split
SR = 5;  % Surrender (else Hit)

%  2  3  4  5  6  7  8  9 10  A
basic.pairStrategyDASA = [
  SP SP SP SP SP SP  H  H  H  H; % 2-2
  SP SP SP SP SP SP  H  H  H  H; % 3-3
   H  H  H SP SP  H  H  H  H  H; % 4-4
  DB DB DB DB DB DB DB DB  H  H; % 5-5
  SP SP SP SP SP  H  H  H  H  H; % 6-6
  SP SP SP SP SP SP  H  H  H  H; % 7-7
  SP SP SP SP SP SP SP SP SP SP; % 8-8
  SP SP SP SP SP  S SP SP  S  S; % 9-9
   S  S  S  S  S  S  S  S  S  S; % 10-10
  SP SP SP SP SP SP SP SP SP SP  % A-A
];

%  2  3  4  5  6  7  8  9 10  A
basic.pairStrategyNoDAS = [
   H  H SP SP SP SP  H  H  H  H; % 2-2
   H  H SP SP SP SP  H  H  H  H; % 3-3
   H  H  H  H  H  H  H  H  H  H; % 4-4
  DB DB DB DB DB DB DB DB  H  H; % 5-5
   H SP SP SP SP  H  H  H  H  H; % 6-6
  SP SP SP SP SP SP  H  H  H  H; % 7-7
  SP SP SP SP SP SP SP SP SP SP; % 8-8
  SP SP SP SP SP  S SP SP  S  S; % 9-9
   S  S  S  S  S  S  S  S  S  S; % 10-10
  SP SP SP SP SP SP SP SP SP SP  % A-A
];
  
   
%  2  3  4  5  6  7  8  9 10  A
basic.softStrategy = [
   H  H  H  H DB  H  H  H  H  H  % 12
   H  H  H  H DB  H  H  H  H  H  % 13
   H  H  H DB DB  H  H  H  H  H; % 14
   H  H DB DB DB  H  H  H  H  H; % 15
   H  H DB DB DB  H  H  H  H  H; % 16   
   H DB DB DB DB  H  H  H  H  H; % 17
   S DS DS DS DS  S  S  H  H  H; % 18
   S  S  S  S  S  S  S  S  S  S; % 19
   S  S  S  S  S  S  S  S  S  S; % 20
   S  S  S  S  S  S  S  S  S  S; % 21
];
  
%  2  3  4  5  6  7  8  9 10  A
basic.hardStrategy = [
   H  H  H  H  H  H  H  H  H  H  % 4
   H  H  H  H  H  H  H  H  H  H  % 5
   H  H  H  H  H  H  H  H  H  H; % 6
   H  H  H  H  H  H  H  H  H  H; % 7
   H  H  H  H  H  H  H  H  H  H; % 8
   H DB DB DB DB  H  H  H  H  H; % 9  
  DB DB DB DB DB DB DB DB  H  H; % 10     
  DB DB DB DB DB DB DB DB DB  H; % 11  
   H  H  S  S  S  H  H  H  H  H; % 12  
   S  S  S  S  S  H  H  H  H  H; % 13
   S  S  S  S  S  H  H  H  H  H; % 14
   S  S  S  S  S  H  H  H SR  H; % 15
   S  S  S  S  S  H  H SR SR SR; % 16
   S  S  S  S  S  S  S  S  S  S; % 17
   S  S  S  S  S  S  S  S  S  S; % 18
   S  S  S  S  S  S  S  S  S  S; % 19
   S  S  S  S  S  S  S  S  S  S; % 20
   S  S  S  S  S  S  S  S  S  S; % 21
 ];

%%% Thorp's Complete Point Count System
NF = inf;

%  2   3   4   5   6   7   8   9  10   A
thorp.hardDrawStand = [
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 4
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 5
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 6
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 7
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 8
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 9
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 10
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 11
  14   6   2  -1   0  NF  NF  NF  NF  NF; % 12
   1  -2  -5  -9  -8  50  NF  NF  NF  NF; % 13
  -5  -8 -13 -17 -17  20  38  NF  NF  NF; % 14
 -12 -17 -21 -26 -28  13  15  12   8  16; % 15
 -21 -25 -30 -34 -35  10  11   6   0  14; % 16
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -15; % 17
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF; % 18
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF; % 19
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF; % 20
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF  % 21
 ];

%  2   3   4   5   6   7   8   9  10   A
thorp.softDrawStand = [
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 12
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 13
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 14
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 15
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 16
  NF  NF  NF  NF  NF  29  NF  NF  NF  NF; % 17
 -NF -NF -NF -NF -NF -NF -NF  NF  12  -6; % 18
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF; % 19
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF; % 20
 -NF -NF -NF -NF -NF -NF -NF -NF -NF -NF  % 21
 ];

%  2   3   4   5   6   7   8   9  10   A
thorp.hardDouble = [
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 4
  NF  NF  NF  20  26  NF  NF  NF  NF  NF; % 5
  NF  NF  27  18  24  NF  NF  NF  NF  NF; % 6
  NF  45  21  14  17  NF  NF  NF  NF  NF; % 7
  NF  22  11   5   5  22  NF  NF  NF  NF; % 8
   3   0  -5 -10 -12   4  14  NF  NF  NF; % 9
 -15 -17 -21 -24 -26 -17  -9  -3   7   6; % 10
 -23 -26 -29 -33 -35 -26 -16 -10  -9  -3; % 11
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 12
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 13
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 14
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 15
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 16
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 17
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 18
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 19
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 20
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF  % 21
 ];

%  2   3   4   5   6   7   8   9  10   A
thorp.softDouble = [
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 12
  NF  10   2 -19 -13  NF  NF  NF  NF  NF; % 13
  NF  11  -3 -13 -19  NF  NF  NF  NF  NF; % 14
  NF  19  -7 -16 -23  NF  NF  NF  NF  NF; % 15
  NF  21  -6 -16 -32  NF  NF  NF  NF  NF; % 16
  NF  -6 -14 -28 -30  NF  NF  NF  NF  NF; % 17
  NF  -2 -15 -18 -23  NF  NF  NF  NF  NF; % 18
  NF   9   5   1   0  NF  NF  NF  NF  NF; % 19
  NF  20  12   8   8  NF  NF  NF  NF  NF; % 20
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF  % 21
 ]; 

%  2   3   4   5   6   7   8   9  10   A
thorp.pairSplit = [
  -9 -15 -22 -30 -NF -NF  NF  NF  NF  NF; % 2-2
 -21 -34 -NF -NF -NF -NF  NF  NF  NF  NF; % 3-3
  NF  18   8   0  NF  NF  NF  NF  NF  NF; % 4-4
  NF  NF  NF  NF  NF  NF  NF  NF  NF  NF; % 5-5
   0  -3  -8 -13 -16  -8  NF  NF  NF  NF; % 6-6
 -22 -29 -35 -NF -NF -NF -NF  NF  NF  NF; % 7-7
 -NF -NF -NF -NF -NF -NF -NF -NF  NF -18; % 8-8
  -3  -8 -10 -15 -14   8 -16 -22  NF  10; % 9-9
  25  17  10   6   7  19  NF  NF  NF  NF; % 10-10
 -NF -NF -NF -NF -NF -33 -24 -22 -20 -17  % A-A
 ];

